using System;
using System.Collections.Generic;
using System.IO;
using UnityEngine;
using UnityEngine.Events;

namespace Armor
{
    public class Mod
    {
        public static void Main()
        {
          CategoryBuilder.Create("Armor", "Anything that can protect you.", ModAPI.LoadSprite("categoryicon.png"));



            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "Greenwich Armor",
                    NameToOrderByOverride = "A - FA",
                    DescriptionOverride = "The armor was created by German craftsmen in cooperation with England. Light enough in comparison with analogues (25 kg).",
                    CategoryOverride = ModAPI.FindCategory("Armor"),
                    ThumbnailOverride = ModAPI.LoadSprite("Greenwich Armor icon.png"),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("upperchestplate.png");

                        int PartCount = 9;

                        if (!Instance.GetComponent<ArmorBehaviour>())
                            Instance.AddComponent<ArmorBehaviour>();

                        ArmorBehaviour armor = Instance.GetComponent<ArmorBehaviour>();

                        ArmorProperties prop = new ArmorProperties();

                        prop.armorPiece = "UpperBody";
                        prop.armorTier = 3;
                        prop.sprite = ModAPI.LoadSprite("Greenwich Armor/upperchestplate.png");
                        prop.armorPoints = 5;

                        armor.prop = prop;
                        armor.SetProperties();

                        ArmorProperties[] armProp = new ArmorProperties[PartCount - 1];

                        armProp[0].sprite = ModAPI.LoadSprite("Greenwich Armor/lowerchestplate.png");
                        armProp[0].armorPiece = "MiddleBody";
                        armProp[0].armorTier = 3;
                        armProp[0].armorPoints = 5;

                        armProp[1].sprite = ModAPI.LoadSprite("Greenwich Armor/faulds.png");
                        armProp[1].armorPiece = "LowerBody";
                        armProp[1].armorTier = 3;
                        armProp[1].armorPoints = 5;

                        armProp[2].sprite = ModAPI.LoadSprite("Greenwich Armor/medievalfauld.png");
                        armProp[2].armorPiece = "UpperLeg";
                        armProp[2].clone = true;
                        armProp[2].armorTier = 3;
                        armProp[2].armorPoints = 5;

                        armProp[3].sprite = ModAPI.LoadSprite("Greenwich Armor/greave.png");
                        armProp[3].armorPiece = "LowerLeg";
                        armProp[3].clone = true;
                        armProp[3].armorTier = 3;
                        armProp[3].armorPoints = 5;

                        armProp[4].sprite = ModAPI.LoadSprite("Greenwich Armor/foot.png");
                        armProp[4].armorPiece = "Foot";
                        armProp[4].armorPoints = 5;
                        armProp[4].armorTier = 3;
                        armProp[4].clone = true;

                        armProp[5].sprite = ModAPI.LoadSprite("Greenwich Armor/leatherPadding.png");
                        armProp[5].armorPiece = "UpperArm";
                        armProp[5].armorPoints = 5;
                        armProp[5].armorTier = 3;
                        armProp[5].clone = true;

                        armProp[6].sprite = ModAPI.LoadSprite("Greenwich Armor/medievalgauntlet.png");
                        armProp[6].armorPiece = "LowerArm";
                        armProp[6].armorPoints = 5;
                        armProp[6].armorTier = 3;
                        armProp[6].clone = true;

                        armProp[7].sprite = ModAPI.LoadSprite("Greenwich Armor/crusaderhelmet.png");
                        armProp[7].armorPiece = "Head";
                        armProp[7].armorTier = 3;
                        armProp[7].armorPoints = 5;

                        if (armor.spawn)
                        {
                          var phys = Instance.GetComponent<PhysicalBehaviour>();
                          Instance.GetComponent<PhysicalBehaviour>().InitialMass = 0f;
                          Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 0.06f;
                          Instance.GetComponent<PhysicalBehaviour>().rigidbody.mass = 0f;

                            armor.SetPieces = new ArmorBehaviour[PartCount - 1];
                            armor.SpawnOtherParts(armProp);
                        }

                        Instance.FixColliders();
                    }
                }
            );

            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "Kastenbrust Armor",
                    NameToOrderByOverride = "A - FA",
                    DescriptionOverride = "Armor made of feminine box chest is not inferior in characteristics to Greenwich armor. Has the longest skirt among the famous.",
                    CategoryOverride = ModAPI.FindCategory("Armor"),
                    ThumbnailOverride = ModAPI.LoadSprite("Kastenbrust Armor icon.png"),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Kastenbrust Armor/upperchestplate2.png");

                        int PartCount = 9;

                        if (!Instance.GetComponent<ArmorBehaviour>())
                            Instance.AddComponent<ArmorBehaviour>();

                        ArmorBehaviour armor = Instance.GetComponent<ArmorBehaviour>();

                        ArmorProperties prop = new ArmorProperties();

                        prop.armorPiece = "UpperBody";
                        prop.armorTier = 3;
                        prop.sprite = ModAPI.LoadSprite("Kastenbrust Armor/upperchestplate2.png");
                        prop.armorPoints = 5;

                        armor.prop = prop;
                        armor.SetProperties();

                        ArmorProperties[] armProp = new ArmorProperties[PartCount - 1];

                        armProp[0].sprite = ModAPI.LoadSprite("Kastenbrust Armor/lowerchestplate2.png");
                        armProp[0].armorPiece = "MiddleBody";
                        armProp[0].armorTier = 3;
                        armProp[0].armorPoints = 5;

                        armProp[1].sprite = ModAPI.LoadSprite("Kastenbrust Armor/faulds2.png");
                        armProp[1].armorPiece = "LowerBody";
                        armProp[1].armorTier = 3;
                        armProp[1].armorPoints = 5;

                        armProp[2].sprite = ModAPI.LoadSprite("Kastenbrust Armor/medievalfauld2.png");
                        armProp[2].armorPiece = "UpperLeg";
                        armProp[2].clone = true;
                        armProp[2].armorTier = 3;
                        armProp[2].armorPoints = 5;

                        armProp[3].sprite = ModAPI.LoadSprite("Kastenbrust Armor/greave2.png");
                        armProp[3].armorPiece = "LowerLeg";
                        armProp[3].clone = true;
                        armProp[3].armorTier = 3;
                        armProp[3].armorPoints = 5;

                        armProp[4].sprite = ModAPI.LoadSprite("Kastenbrust Armor/foot2.png");
                        armProp[4].armorPiece = "Foot";
                        armProp[4].armorPoints = 5;
                        armProp[4].armorTier = 3;
                        armProp[4].clone = true;

                        armProp[5].sprite = ModAPI.LoadSprite("Kastenbrust Armor/leatherPadding2.png");
                        armProp[5].armorPiece = "UpperArm";
                        armProp[5].armorPoints = 5;
                        armProp[5].armorTier = 3;
                        armProp[5].clone = true;

                        armProp[6].sprite = ModAPI.LoadSprite("Kastenbrust Armor/medievalgauntlet2.png");
                        armProp[6].armorPiece = "LowerArm";
                        armProp[6].armorPoints = 5;
                        armProp[6].armorTier = 3;
                        armProp[6].clone = true;

                        armProp[7].sprite = ModAPI.LoadSprite("Kastenbrust Armor/crusaderhelmet2.png");
                        armProp[7].armorPiece = "Head";
                        armProp[7].armorTier = 3;
                        armProp[7].armorPoints = 5;

                        if (armor.spawn)
                        {
                          var phys = Instance.GetComponent<PhysicalBehaviour>();
                          Instance.GetComponent<PhysicalBehaviour>().InitialMass = 0f;
                          Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 0.06f;
                          Instance.GetComponent<PhysicalBehaviour>().rigidbody.mass = 0f;

                            armor.SetPieces = new ArmorBehaviour[PartCount - 1];
                            armor.SpawnOtherParts(armProp);
                        }

                        Instance.FixColliders();
                    }
                }
            );

            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "Stechzeug Armor",
                    NameToOrderByOverride = "A - FA",
                    DescriptionOverride = "Tournament armor designed for maximum head protection from spikes. It is one of the heaviest armor ever made.",
                    CategoryOverride = ModAPI.FindCategory("Armor"),
                    ThumbnailOverride = ModAPI.LoadSprite("Stechzeug Armor icon.png"),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Stechzeug Armor/upperchestplate3.png");
                        int PartCount = 9;

                        if (!Instance.GetComponent<ArmorBehaviour>())
                            Instance.AddComponent<ArmorBehaviour>();

                        ArmorBehaviour armor = Instance.GetComponent<ArmorBehaviour>();

                        ArmorProperties prop = new ArmorProperties();

                        prop.armorPiece = "UpperBody";
                        prop.armorTier = 4;
                        prop.sprite = ModAPI.LoadSprite("Stechzeug Armor/upperchestplate3.png");
                        prop.armorPoints = 5;

                        armor.prop = prop;
                        armor.SetProperties();

                        ArmorProperties[] armProp = new ArmorProperties[PartCount - 1];

                        armProp[0].sprite = ModAPI.LoadSprite("Stechzeug Armor/lowerchestplate3.png");
                        armProp[0].armorPiece = "MiddleBody";
                        armProp[0].armorTier = 4;
                        armProp[0].armorPoints = 5;

                        armProp[1].sprite = ModAPI.LoadSprite("Stechzeug Armor/faulds3.png");
                        armProp[1].armorPiece = "LowerBody";
                        armProp[1].armorTier = 4;
                        armProp[1].armorPoints = 5;

                        armProp[2].sprite = ModAPI.LoadSprite("Stechzeug Armor/medievalfauld3.png");
                        armProp[2].armorPiece = "UpperLeg";
                        armProp[2].clone = true;
                        armProp[2].armorTier = 4;
                        armProp[2].armorPoints = 5;

                        armProp[3].sprite = ModAPI.LoadSprite("Stechzeug Armor/greave3.png");
                        armProp[3].armorPiece = "LowerLeg";
                        armProp[3].clone = true;
                        armProp[3].armorTier = 4;
                        armProp[3].armorPoints = 5;

                        armProp[4].sprite = ModAPI.LoadSprite("Stechzeug Armor/foot3.png");
                        armProp[4].armorPiece = "Foot";
                        armProp[4].armorPoints = 5;
                        armProp[4].armorTier = 4;
                        armProp[4].clone = true;

                        armProp[5].sprite = ModAPI.LoadSprite("Stechzeug Armor/leatherPadding3.png");
                        armProp[5].armorPiece = "UpperArm";
                        armProp[5].armorPoints = 5;
                        armProp[5].armorTier = 4;
                        armProp[5].clone = true;

                        armProp[6].sprite = ModAPI.LoadSprite("Stechzeug Armor/medievalgauntlet3.png");
                        armProp[6].armorPiece = "LowerArm";
                        armProp[6].armorPoints = 5;
                        armProp[6].armorTier = 4;
                        armProp[6].clone = true;

                        armProp[7].sprite = ModAPI.LoadSprite("Stechzeug Armor/crusaderhelmet3.png");
                        armProp[7].armorPiece = "Head";
                        armProp[7].armorTier = 4;
                        armProp[7].armorPoints = 5;

                        if (armor.spawn)
                        {
                          var phys = Instance.GetComponent<PhysicalBehaviour>();
                          Instance.GetComponent<PhysicalBehaviour>().InitialMass = 0f;
                          Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 0.064f;
                          Instance.GetComponent<PhysicalBehaviour>().rigidbody.mass = 0f;

                            armor.SetPieces = new ArmorBehaviour[PartCount - 1];
                            armor.SpawnOtherParts(armProp);
                        }

                        Instance.FixColliders();
                    }
                }
            );

            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "Hussite crossbowmen Armor",
                    NameToOrderByOverride = "A - FA",
                    DescriptionOverride = "Armor designed for crossbowmen. Possesses mediocre characteristics. Covered with chain mail as a bonus.",
                    CategoryOverride = ModAPI.FindCategory("Armor"),
                    ThumbnailOverride = ModAPI.LoadSprite("Stech Armor icon.png"),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Hussite crossbowmen Armor/upperchestplate4.png");

                        int PartCount = 7;

                        if (!Instance.GetComponent<ArmorBehaviour>())
                            Instance.AddComponent<ArmorBehaviour>();

                        ArmorBehaviour armor = Instance.GetComponent<ArmorBehaviour>();

                        ArmorProperties prop = new ArmorProperties();

                        prop.armorPiece = "UpperBody";
                        prop.armorTier = 4;
                        prop.sprite = ModAPI.LoadSprite("Hussite crossbowmen Armor/upperchestplate4.png");
                        prop.armorPoints = 5;

                        armor.prop = prop;
                        armor.SetProperties();

                        ArmorProperties[] armProp = new ArmorProperties[PartCount - 1];

                        armProp[0].sprite = ModAPI.LoadSprite("Hussite crossbowmen Armor/lowerchestplate4.png");
                        armProp[0].armorPiece = "MiddleBody";
                        armProp[0].armorTier = 4;
                        armProp[0].armorPoints = 5;

                        armProp[1].sprite = ModAPI.LoadSprite("Hussite crossbowmen Armor/faulds4.png");
                        armProp[1].armorPiece = "LowerBody";
                        armProp[1].armorTier = 2;
                        armProp[1].armorPoints = 10;

                        armProp[2].sprite = ModAPI.LoadSprite("Hussite crossbowmen Armor/medievalfauld4.png");
                        armProp[2].armorPiece = "UpperLeg";
                        armProp[2].clone = true;
                        armProp[2].armorTier = 4;
                        armProp[2].armorPoints = 5;

                        armProp[3].sprite = ModAPI.LoadSprite("Hussite crossbowmen Armor/leatherPadding4.png");
                        armProp[3].armorPiece = "UpperArm";
                        armProp[3].armorPoints = 5;
                        armProp[3].armorTier = 2;
                        armProp[3].clone = true;

                        armProp[4].sprite = ModAPI.LoadSprite("Hussite crossbowmen Armor/medievalgauntlet4.png");
                        armProp[4].armorPiece = "LowerArm";
                        armProp[4].armorPoints = 5;
                        armProp[4].armorTier = 2;
                        armProp[4].clone = true;

                        armProp[5].sprite = ModAPI.LoadSprite("Hussite crossbowmen Armor/crusaderhelmet4.png", 4.0f);
                        armProp[5].armorPiece = "Head";
                        armProp[5].armorTier = 3;
                        armProp[5].armorPoints = 5;
                        armProp[5].customCollider = true;

                        if (armor.spawn)
                        {
                          var phys = Instance.GetComponent<PhysicalBehaviour>();
                          Instance.GetComponent<PhysicalBehaviour>().InitialMass = 0f;
                          Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 0.052f;
                          Instance.GetComponent<PhysicalBehaviour>().rigidbody.mass = 0f;

                            armor.SetPieces = new ArmorBehaviour[PartCount - 1];
                            armor.SpawnOtherParts(armProp);
                        }

                        Instance.FixColliders();
                    }
                }
            );

            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "Crusader Armor",
                    NameToOrderByOverride = "A - FA",
                    DescriptionOverride = "Light armor of the knights of the templar order. It is 80% chain mail and you should not expect good protection. But the helmet is the best against slashing weapons.",
                    CategoryOverride = ModAPI.FindCategory("Armor"),
                    ThumbnailOverride = ModAPI.LoadSprite("Crusader Armor icon.png"),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Crusader Armor/upperchestplate5.png");

                        int PartCount = 9;

                        if (!Instance.GetComponent<ArmorBehaviour>())
                            Instance.AddComponent<ArmorBehaviour>();

                        ArmorBehaviour armor = Instance.GetComponent<ArmorBehaviour>();

                        ArmorProperties prop = new ArmorProperties();

                        prop.armorPiece = "UpperBody";
                        prop.armorTier = 2;
                        prop.sprite = ModAPI.LoadSprite("Crusaider Armor/upperchestplate5.png");
                        prop.armorPoints = 5;

                        armor.prop = prop;
                        armor.SetProperties();

                        ArmorProperties[] armProp = new ArmorProperties[PartCount - 1];

                        armProp[0].sprite = ModAPI.LoadSprite("Crusaider Armor/lowerchestplate5.png");
                        armProp[0].armorPiece = "MiddleBody";
                        armProp[0].armorTier = 2;
                        armProp[0].armorPoints = 5;

                        armProp[1].sprite = ModAPI.LoadSprite("Crusaider Armor/faulds5.png");
                        armProp[1].armorPiece = "LowerBody";
                        armProp[1].armorTier = 2;
                        armProp[1].armorPoints = 10;

                        armProp[2].sprite = ModAPI.LoadSprite("Crusaider Armor/medievalfauld5.png");
                        armProp[2].armorPiece = "UpperLeg";
                        armProp[2].clone = true;
                        armProp[2].armorTier = 2;
                        armProp[2].armorPoints = 5;

                        armProp[3].sprite = ModAPI.LoadSprite("Crusaider Armor/greave5.png");
                        armProp[3].armorPiece = "LowerLeg";
                        armProp[3].clone = true;
                        armProp[3].armorTier = 2;
                        armProp[3].armorPoints = 5;

                        armProp[4].sprite = ModAPI.LoadSprite("Crusaider Armor/foot5.png");
                        armProp[4].armorPiece = "Foot";
                        armProp[4].armorPoints = 5;
                        armProp[4].armorTier = 2;
                        armProp[4].clone = true;

                        armProp[5].sprite = ModAPI.LoadSprite("Crusaider Armor/leatherPadding5.png");
                        armProp[5].armorPiece = "UpperArm";
                        armProp[5].armorPoints = 5;
                        armProp[5].armorTier = 2;
                        armProp[5].clone = true;

                        armProp[6].sprite = ModAPI.LoadSprite("Crusaider Armor/medievalgauntlet5.png");
                        armProp[6].armorPiece = "LowerArm";
                        armProp[6].armorPoints = 5;
                        armProp[6].armorTier = 2;
                        armProp[6].clone = true;

                        armProp[7].sprite = ModAPI.LoadSprite("Crusaider Armor/crusaderhelmet5.png");
                        armProp[7].armorPiece = "Head";
                        armProp[7].armorTier = 4;
                        armProp[7].armorPoints = 5;
                        armProp[7].customCollider = true;

                        if (armor.spawn)
                        {
                          var phys = Instance.GetComponent<PhysicalBehaviour>();
                          Instance.GetComponent<PhysicalBehaviour>().InitialMass = 0f;
                          Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 0.05f;
                          Instance.GetComponent<PhysicalBehaviour>().rigidbody.mass = 0f;

                            armor.SetPieces = new ArmorBehaviour[PartCount - 1];
                            armor.SpawnOtherParts(armProp);
                        }

                        Instance.FixColliders();
                    }
                }
            );

            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "Arabic Armor",
                    NameToOrderByOverride = "A - FA",
                    DescriptionOverride = "Eternal foe to the armor of the Crusaders, but with a greater advantage in defense.",
                    CategoryOverride = ModAPI.FindCategory("Armor"),
                    ThumbnailOverride = ModAPI.LoadSprite("Arabic Armor icon.png"),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Arabic Armor/upperchestplate6.png");

                        int PartCount = 6;

                        if (!Instance.GetComponent<ArmorBehaviour>())
                            Instance.AddComponent<ArmorBehaviour>();

                        ArmorBehaviour armor = Instance.GetComponent<ArmorBehaviour>();

                        ArmorProperties prop = new ArmorProperties();

                        prop.armorPiece = "UpperBody";
                        prop.armorTier = 3;
                        prop.sprite = ModAPI.LoadSprite("Arabic Armor/upperchestplate6.png");
                        prop.armorPoints = 5;

                        armor.prop = prop;
                        armor.SetProperties();

                        ArmorProperties[] armProp = new ArmorProperties[PartCount - 1];

                        armProp[0].sprite = ModAPI.LoadSprite("Arabic Armor/lowerchestplate6.png");
                        armProp[0].armorPiece = "MiddleBody";
                        armProp[0].armorTier = 3;
                        armProp[0].armorPoints = 5;

                        armProp[1].sprite = ModAPI.LoadSprite("Arabic Armor/faulds6.png");
                        armProp[1].armorPiece = "LowerBody";
                        armProp[1].armorTier = 3;
                        armProp[1].armorPoints = 5;

                        armProp[2].sprite = ModAPI.LoadSprite("Arabic Armor/leatherPadding6.png");
                        armProp[2].armorPiece = "UpperArm";
                        armProp[2].armorPoints = 5;
                        armProp[2].armorTier = 2;
                        armProp[2].clone = true;

                        armProp[3].sprite = ModAPI.LoadSprite("Arabic Armor/medievalgauntlet6.png");
                        armProp[3].armorPiece = "LowerArm";
                        armProp[3].armorPoints = 5;
                        armProp[3].armorTier = 3;
                        armProp[3].clone = true;

                        armProp[4].sprite = ModAPI.LoadSprite("Arabic Armor/crusaderhelmet6.png");
                        armProp[4].armorPiece = "Head";
                        armProp[4].armorTier = 3;
                        armProp[4].armorPoints = 5;
                        armProp[4].customCollider = true;

                        if (armor.spawn)
                        {
                          var phys = Instance.GetComponent<PhysicalBehaviour>();
                          Instance.GetComponent<PhysicalBehaviour>().InitialMass = 0f;
                          Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 0.06f;
                          Instance.GetComponent<PhysicalBehaviour>().rigidbody.mass = 0f;

                            armor.SetPieces = new ArmorBehaviour[PartCount - 1];
                            armor.SpawnOtherParts(armProp);
                        }

                        Instance.FixColliders();
                    }
                }
            );

            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "Mongolian Armor",
                    NameToOrderByOverride = "A - FA",
                    DescriptionOverride = "Heavy leather armor of the Great Horde archers.",
                    CategoryOverride = ModAPI.FindCategory("Armor"),
                    ThumbnailOverride = ModAPI.LoadSprite("Mongolian Armor icon.png"),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Mongolian Armor/upperchestplate7.png");

                        int PartCount = 6;

                        if (!Instance.GetComponent<ArmorBehaviour>())
                            Instance.AddComponent<ArmorBehaviour>();

                        ArmorBehaviour armor = Instance.GetComponent<ArmorBehaviour>();

                        ArmorProperties prop = new ArmorProperties();

                        prop.armorPiece = "UpperBody";
                        prop.armorTier = 3;
                        prop.sprite = ModAPI.LoadSprite("Mongolian Armor/upperchestplate7.png");
                        prop.armorPoints = 5;

                        armor.prop = prop;
                        armor.SetProperties();

                        ArmorProperties[] armProp = new ArmorProperties[PartCount - 1];

                        armProp[0].sprite = ModAPI.LoadSprite("Mongolian Armor/lowerchestplate7.png");
                        armProp[0].armorPiece = "MiddleBody";
                        armProp[0].armorTier = 3;
                        armProp[0].armorPoints = 5;

                        armProp[1].sprite = ModAPI.LoadSprite("Mongolian Armor/faulds7.png");
                        armProp[1].armorPiece = "LowerBody";
                        armProp[1].armorTier = 3;
                        armProp[1].armorPoints = 5;

                        armProp[2].sprite = ModAPI.LoadSprite("Mongolian Armor/leatherPadding7.png");
                        armProp[2].armorPiece = "UpperArm";
                        armProp[2].armorPoints = 5;
                        armProp[2].armorTier = 3;
                        armProp[2].clone = true;

                        armProp[3].sprite = ModAPI.LoadSprite("Mongolian Armor/medievalgauntlet7.png");
                        armProp[3].armorPiece = "LowerArm";
                        armProp[3].armorPoints = 5;
                        armProp[3].armorTier = 2;
                        armProp[3].clone = true;

                        armProp[4].sprite = ModAPI.LoadSprite("Mongolian Armor/crusaderhelmet7.png");
                        armProp[4].armorPiece = "Head";
                        armProp[4].armorTier = 3;
                        armProp[4].armorPoints = 5;
                        armProp[4].customCollider = true;

                        if (armor.spawn)
                        {
                          var phys = Instance.GetComponent<PhysicalBehaviour>();
                          Instance.GetComponent<PhysicalBehaviour>().InitialMass = 0f;
                          Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 0.06f;
                          Instance.GetComponent<PhysicalBehaviour>().rigidbody.mass = 0f;

                            armor.SetPieces = new ArmorBehaviour[PartCount - 1];
                            armor.SpawnOtherParts(armProp);
                        }

                        Instance.FixColliders();
                    }
                }
            );

            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "Brigantine",
                    NameToOrderByOverride = "A - FA",
                    DescriptionOverride = "Light plate armor, the squeak of 14th century fashion.",
                    CategoryOverride = ModAPI.FindCategory("Armor"),
                    ThumbnailOverride = ModAPI.LoadSprite("Brigantine icon.png"),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Brigantine/upperchestplate8.png", 2.0f);

                        int PartCount = 4;

                        if (!Instance.GetComponent<ArmorBehaviour>())
                            Instance.AddComponent<ArmorBehaviour>();

                        ArmorBehaviour armor = Instance.GetComponent<ArmorBehaviour>();

                        ArmorProperties prop = new ArmorProperties();

                        prop.armorPiece = "UpperBody";
                        prop.armorTier = 3;
                        prop.sprite = ModAPI.LoadSprite("Brigantine/upperchestplate8.png", 2.0f);
                        prop.armorPoints = 5;

                        armor.prop = prop;
                        armor.SetProperties();

                        ArmorProperties[] armProp = new ArmorProperties[PartCount - 1];

                        armProp[0].sprite = ModAPI.LoadSprite("Brigantine/lowerchestplate8.png", 2.0f);
                        armProp[0].armorPiece = "MiddleBody";
                        armProp[0].armorTier = 3;
                        armProp[0].armorPoints = 5;

                        armProp[1].sprite = ModAPI.LoadSprite("Brigantine/faulds8.png", 2.0f);
                        armProp[1].armorPiece = "LowerBody";
                        armProp[1].armorTier = 3;
                        armProp[1].armorPoints = 5;

                        armProp[2].sprite = ModAPI.LoadSprite("Brigantine/leatherPadding8.png", 2.0f);
                        armProp[2].armorPiece = "UpperArm";
                        armProp[2].armorTier = 3;
                        armProp[2].armorPoints = 5;
                        armProp[2].clone = true;
                        armProp[2].customCollider = true;


                        if (armor.spawn)
                        {
                          var phys = Instance.GetComponent<PhysicalBehaviour>();
                          Instance.GetComponent<PhysicalBehaviour>().InitialMass = 0f;
                          Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 0.05f;
                          Instance.GetComponent<PhysicalBehaviour>().rigidbody.mass = 0f;

                            armor.SetPieces = new ArmorBehaviour[PartCount - 1];
                            armor.SpawnOtherParts(armProp);
                        }

                        Instance.FixColliders();
                    }
                }
            );

            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "Crown",
                    NameToOrderByOverride = "A - FA",
                    DescriptionOverride = "The crown is yours without dispute, only if you can carry it on your head!",
                    CategoryOverride = ModAPI.FindCategory("Armor"),
                    ThumbnailOverride = ModAPI.LoadSprite("Crown icon.png"),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Decorations/Crown.png", 2.0f);

                        int PartCount = 6;

                        if (!Instance.GetComponent<ArmorBehaviour>())
                            Instance.AddComponent<ArmorBehaviour>();

                        ArmorBehaviour armor = Instance.GetComponent<ArmorBehaviour>();

                        ArmorProperties prop = new ArmorProperties();

                        prop.armorPiece = "Head";
                        prop.armorTier = 4;
                        prop.sprite = ModAPI.LoadSprite("Decorations/Crown.png", 2.0f);
                        prop.armorPoints = 5;

                        armor.prop = prop;
                        armor.SetProperties();

                        ArmorProperties[] armProp = new ArmorProperties[PartCount - 1];

                        if (armor.spawn)
                        {
                            armor.SetPieces = new ArmorBehaviour[PartCount - 1];
                            armor.SpawnOtherParts(armProp);
                        }

                        Instance.FixColliders();
                    }
                }
            );

            ModAPI.Register(
      new Modification()
      {
          OriginalItem = ModAPI.FindSpawnable("Hammer"),
          NameOverride = "Long Mace",
          DescriptionOverride = "A huge hedgehog capable of crushing armor.",
          CategoryOverride = ModAPI.FindCategory("Melee"),
          ThumbnailOverride = ModAPI.LoadSprite("Icons/Long mace icon.png"),
          AfterSpawn = (Instance) =>
          {
              var phys = Instance.GetComponent<PhysicalBehaviour>();
              Instance.GetComponent<PhysicalBehaviour>().InitialMass = 1f;
              Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 1f;
              Instance.GetComponent<PhysicalBehaviour>().rigidbody.mass = 9f;


              Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Long mace.png", 2.0f);
              Instance.FixColliders();
          }
      }
  );

  ModAPI.Register(
      new Modification()
      {
          OriginalItem = ModAPI.FindSpawnable("Hammer"),
          NameOverride = "Mace",
          DescriptionOverride = "A weapon with a protective effect is one-handed. Used as a symbol of power.",
          CategoryOverride = ModAPI.FindCategory("Melee"),
          ThumbnailOverride = ModAPI.LoadSprite("Icons/Mace icon.png"),
          AfterSpawn = (Instance) =>
          {
              var phys = Instance.GetComponent<PhysicalBehaviour>();
              Instance.GetComponent<PhysicalBehaviour>().InitialMass = 1f;
              Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 1f;
              Instance.GetComponent<PhysicalBehaviour>().rigidbody.mass = 5f;

              Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Mace.png", 2.0f);

              Instance.FixColliders();
          }
      }
  );

  ModAPI.Register(
      new Modification()
      {
          OriginalItem = ModAPI.FindSpawnable("Knife"),
          NameOverride = "Polox",
          DescriptionOverride = "A hybrid of an ax and a hammer placed on a long shaft.",
          CategoryOverride = ModAPI.FindCategory("Melee"),
          ThumbnailOverride = ModAPI.LoadSprite("Icons/Halberd icon.png"),
          AfterSpawn = (Instance) =>
          {
              var phys = Instance.GetComponent<PhysicalBehaviour>();
              Instance.GetComponent<PhysicalBehaviour>().InitialMass = 1f;
              Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 1f;
              Instance.GetComponent<PhysicalBehaviour>().rigidbody.mass = 6f;

              Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Halberd.png", 2.0f);

              Instance.FixColliders();
          }
      }
  );

  ModAPI.Register(
      new Modification()
      {
          OriginalItem = ModAPI.FindSpawnable("Knife"),
          NameOverride = "Lucerne Hammer",
          DescriptionOverride = "A large hammer on a shaft with an embossing on the second side. At one time it was a storm of knights.",
          CategoryOverride = ModAPI.FindCategory("Melee"),
          ThumbnailOverride = ModAPI.LoadSprite("Icons/Lucerne hammer icon.png"),
          AfterSpawn = (Instance) =>
          {
              var phys = Instance.GetComponent<PhysicalBehaviour>();
              Instance.GetComponent<PhysicalBehaviour>().InitialMass = 1f;
              Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 1f;
              Instance.GetComponent<PhysicalBehaviour>().rigidbody.mass = 6f;

              Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Lucerne hammer.png", 2.0f);

              Instance.FixColliders();
          }
      }
  );

  ModAPI.Register(
      new Modification()
      {
          OriginalItem = ModAPI.FindSpawnable("Knife"),
          NameOverride = "Little Lucerne Hammer",
          DescriptionOverride = "Small but destructive hammer with a coin.",
          CategoryOverride = ModAPI.FindCategory("Melee"),
          ThumbnailOverride = ModAPI.LoadSprite("Icons/Little lucerne hammer icon.png"),
          AfterSpawn = (Instance) =>
          {
              var phys = Instance.GetComponent<PhysicalBehaviour>();
              Instance.GetComponent<PhysicalBehaviour>().InitialMass = 1f;
              Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 1f;
              Instance.GetComponent<PhysicalBehaviour>().rigidbody.mass = 4.5f;

              Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Little lucerne hammer.png", 2.0f);

              Instance.FixColliders();
          }
      }
  );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Spear"),
                      NameOverride = "Alshpis",
                      DescriptionOverride = "Long spear designed for throwing. Has stops under the blade.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Alshpis icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Alshpis.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Spear"),
                      NameOverride = "East Spear",
                      DescriptionOverride = "A spear with a wide feather and a powerful shaft. It was very popular in the east.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/East spear icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/East spear.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Spear"),
                      NameOverride = "Harpoon",
                      DescriptionOverride = "Light spears with jagged edges and all sorts of parts that get in the way of pulling it out.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Harpoon icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Harpoon.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Spear"),
                      NameOverride = "Guisarma",
                      DescriptionOverride = "A close relative of the glaive. It differs in the angle at which the protruding part is located.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Guisarma icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Guisarma.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Knife"),
                      NameOverride = "Glaive",
                      DescriptionOverride = "A wide ax with a long shaft that should cut the legs of horses and stop the blades with a bent end.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Glaive icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Glaive.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Spear"),
                      NameOverride = "Pitchfork",
                      DescriptionOverride = "A combat version of a peasant weapon. Can effectively stab and stop blows.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Pitchfork icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Pitchfork.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Spear"),
                      NameOverride = "Two-handed Sword",
                      DescriptionOverride = "An expensive sword with two handles. Due to the fact that the weapon weighs more than 2 kilograms, it cannot be operated with one hand.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Two-handed sword icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Two-handed sword.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Sword"),
                      NameOverride = "Rapier",
                      DescriptionOverride = "A thin blade with a complex guard. Capable of thrusting blows.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Rapier icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Rapier.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Sword"),
                      NameOverride = "Gross Messer",
                      DescriptionOverride = "A large knife with a unique hilt and heavy blade.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Gross messer icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Gross messer.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Knife"),
                      NameOverride = "Saber",
                      DescriptionOverride = "The eastern curved blade is excellent for slashing attacks against an unprotected foe.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Saber icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Saber.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Knife"),
                      NameOverride = "Stylet",
                      DescriptionOverride = "A short knife with a simple guard.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Stylet icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Stylet.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Knife"),
                      NameOverride = "Saxon",
                      DescriptionOverride = "The knife is named after the peoples of the West. It is very easy to manufacture and does not have a guard.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Saxon icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Saxon.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Knife"),
                      NameOverride = "Daga",
                      DescriptionOverride = "The wide blade is good for a stealthy backstab. Has reverse brush protection.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Daga icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Daga.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Knife"),
                      NameOverride = "Spanish Daga",
                      DescriptionOverride = "A short blade with a complex guard. Good in conjunction with a rapier.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Spanish daga icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Spanish daga.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Knife"),
                      NameOverride = "Swordbreaker",
                      DescriptionOverride = "The wide blade has holes for catching balls and disarming the enemy.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Swordbreaker icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Swordbreaker.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Knife"),
                      NameOverride = "Sea Swordbreaker",
                      DescriptionOverride = "The marine specimen of the swordbreaker has a narrow blade and a saber-like guard.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Sea swordbreaker icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Sea swordbreaker.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Knife"),
                      NameOverride = "Estoc",
                      DescriptionOverride = "The marine specimen of the swordbreaker has a narrow blade and a saber-like guard.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Estoc icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Estoc.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Knife"),
                      NameOverride = "Falchion",
                      DescriptionOverride = "Large and wide knife. Can replace primary weapons.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Falchion icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Falchion.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Knife"),
                      NameOverride = "Nosed Falchion",
                      DescriptionOverride = "A type of falchion with a more convex blade.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Nosed falchion icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Nosed falchion.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Knife"),
                      NameOverride = "Nizaricordia",
                      DescriptionOverride = "Wide faceted dagger for piercing armor.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Nizaricordia icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Nizaricordia.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Knife"),
                      NameOverride = "Scimitar Uruk Hai",
                      DescriptionOverride = "A small bonus in the form of an orc broadsword you know from where.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Scimitar Uruk Hai icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Scimitar Uruk Hai.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Knife"),
                      NameOverride = "Cutlass",
                      DescriptionOverride = "Large pirate saber.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Cutlass icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Cutlass.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Sword"),
                      NameOverride = "Boarding Sword",
                      DescriptionOverride = "The duelist sword is from Spain. There is a complex hand defense.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Boarding sword icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Boarding sword.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Knife"),
                      NameOverride = "Ax",
                      DescriptionOverride = "Ax with a long, convex blade.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Ax icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Ax.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Knife"),
                      NameOverride = "Poleaxe",
                      DescriptionOverride = "A long and powerful ax for the most epic warriors.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Poleaxe icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Poleaxe.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Knife"),
                      NameOverride = "Stachelstock",
                      DescriptionOverride = "A club with barbed rings at the end.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Stachelstock icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        Instance.GetComponent<PhysicalBehaviour>().InitialMass = 1f;
                        Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 1f;
                        Instance.GetComponent<PhysicalBehaviour>().rigidbody.mass = 2f;

                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Stachelstock.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Sword"),
                      NameOverride = "Scythe",
                      DescriptionOverride = "A common peasant tool with a sharp end.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Scythe icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Scythe.png", 2.0f);

                          Instance.FixColliders();
                      }
                  }
              );

              ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Crossbow"),
                     NameOverride = "Bow",
                     DescriptionOverride = "English bow.",
                     CategoryOverride = ModAPI.FindCategory("Firearms"),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Bow icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Bow.png", 3.0f);
                         Instance.GetComponent<SpriteRenderer>().sortingOrder = 1;
                         Instance.GetComponent<ProjectileLauncherBehaviour>().projectileAsset = ModAPI.FindSpawnable("Arrow");
                         Instance.GetComponent<ProjectileLauncherBehaviour>().projectileLaunchStrength = 1.75f;
                         Instance.FixColliders();
                      }
                 }
             );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Crossbow Bolt"),
                      NameOverride = "Arrow",
                      DescriptionOverride = "Lightweight and cheap arrow.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Arrow icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Arrow.png", 3.0f);
                      }
                  }
              );

              ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Crossbow"),
                     NameOverride = "Composite Bow",
                     DescriptionOverride = "Difficult Mongol bow to make. Outperforms European counterparts in strength.",
                     CategoryOverride = ModAPI.FindCategory("Firearms"),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Mongolian bow icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Composite Bow.png", 3.0f);
                         Instance.GetComponent<SpriteRenderer>().sortingOrder = 1;
                         Instance.GetComponent<ProjectileLauncherBehaviour>().projectileAsset = ModAPI.FindSpawnable("Mongolian Arrow");
                         Instance.GetComponent<ProjectileLauncherBehaviour>().projectileLaunchStrength = 2.25f;
                         Instance.FixColliders();
                      }
                 }
             );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Crossbow Bolt"),
                      NameOverride = "Mongolian Arrow",
                      DescriptionOverride = "Custom arrow made with a reverse blade and expensive plumage",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Mongolian arrow icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Mongolian Arrow.png", 3.0f);
                      }
                  }
              );

              ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Crossbow"),
                     NameOverride = "Old Crossbow",
                     DescriptionOverride = "Heavy and powerful crossbow with iron shoulders and wheel tension.",
                     CategoryOverride = ModAPI.FindCategory("Firearms"),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Crossbow icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Crossbow.png", 2.3f);
                         Instance.GetComponent<SpriteRenderer>().sortingOrder = 1;
                         Instance.GetComponent<ProjectileLauncherBehaviour>().projectileAsset = ModAPI.FindSpawnable("Old Bolt");
                         Instance.GetComponent<ProjectileLauncherBehaviour>().projectileLaunchStrength = 3f;
                         Instance.FixColliders();
                      }
                 }
             );

              ModAPI.Register(
                  new Modification()
                  {
                      OriginalItem = ModAPI.FindSpawnable("Crossbow Bolt"),
                      NameOverride = "Old Bolt",
                      DescriptionOverride = "Reverse taper heavy crossbow bolt.",
                      CategoryOverride = ModAPI.FindCategory("Melee"),
                      ThumbnailOverride = ModAPI.LoadSprite("Icons/Old bolt icon.png"),
                      AfterSpawn = (Instance) =>
                      {
                          Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Old bolt.png", 2.0f);
                      }
                  }
              );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Stick"),
                     NameOverride = "Shield",
                     DescriptionOverride = "Wooden Norman shield. Provides mediocre protection against arrows.",
                     CategoryOverride = ModAPI.FindCategory("Armor"),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/shield icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Shields/shield.png");

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Stick"),
                     NameOverride = "Shield 'Red Cross'",
                     DescriptionOverride = "Shield with color.",
                     CategoryOverride = ModAPI.FindCategory("Armor"),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/shield2 icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Shields/shield2.png");

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Stick"),
                     NameOverride = "Shield 'Switzerland'",
                     DescriptionOverride = "Shield with color.",
                     CategoryOverride = ModAPI.FindCategory("Armor"),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/shield3 icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Shields/shield3.png");

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Rod"),
                     NameOverride = "Metal Shield",
                     DescriptionOverride = "A shield made of steel. Reliably protects against all weapons.",
                     CategoryOverride = ModAPI.FindCategory("Armor"),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Metal shield icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Shields/Metal shield.png");

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Rod"),
                     NameOverride = "Metal Shield 'Red Cross'",
                     DescriptionOverride = "Painted steel shield.",
                     CategoryOverride = ModAPI.FindCategory("Armor"),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Metal shield2 icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Shields/Metal shield2.png");

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Rod"),
                     NameOverride = "Metal Shield 'Jester'",
                     DescriptionOverride = "Painted steel shield.",
                     CategoryOverride = ModAPI.FindCategory("Armor"),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Metal shield3 icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Shields/Metal shield3.png");

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Stick"),
                     NameOverride = "Ride shield",
                     DescriptionOverride = "A large kite shield used by the riders.",
                     CategoryOverride = ModAPI.FindCategory("Armor"),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Ride shield icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Shields/Ride shield.png");

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Stick"),
                     NameOverride = "Ride Shield 'Vortex'",
                     DescriptionOverride = "Large, colored teardrop shield.",
                     CategoryOverride = ModAPI.FindCategory("Armor"),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Ride shield2 icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Shields/Ride shield2.png");

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Stick"),
                     NameOverride = "Ride Shield 'Star'",
                     DescriptionOverride = "Large, colored teardrop shield.",
                     CategoryOverride = ModAPI.FindCategory("Armor"),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Ride shield3 icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Shields/Ride shield3.png");

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Rod"),
                     NameOverride = "Buckler",
                     DescriptionOverride = "Small metal shield for a duel.",
                     CategoryOverride = ModAPI.FindCategory("Armor"),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Buckler icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Shields/Buckler.png");

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Rod"),
                     NameOverride = "Leather Buckler",
                     DescriptionOverride = "Small metal shield for duel covered with leather.",
                     CategoryOverride = ModAPI.FindCategory("Armor"),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Buckler2 icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Shields/Buckler2.png");

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Stick"),
                     NameOverride = "Tower Shield",
                     DescriptionOverride = "Large shield of crossbowmen behind which it is convenient to reload.",
                     CategoryOverride = ModAPI.FindCategory("Armor"),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Tower shield icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Shields/Tower shield.png");

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Stick"),
                     NameOverride = "Tower Shield 'Icon'",
                     DescriptionOverride = "A large crossbow shield with a beautiful design.",
                     CategoryOverride = ModAPI.FindCategory("Armor"),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Tower shield2 icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Shields/Tower shield2.png");

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Stick"),
                     NameOverride = "Side Shield",
                     DescriptionOverride = "Decorative shield.",
                     CategoryOverride = ModAPI.FindCategory("Misc."),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Side shield icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Decorations/Side shield.png", 2.0f);

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Wheel"),
                     NameOverride = "Side Shield 'Red Cross'",
                     DescriptionOverride = "Decorative shield.",
                     CategoryOverride = ModAPI.FindCategory("Misc."),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Side shield2 icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Decorations/Side shield2.png", 2.0f);

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Wheel"),
                     NameOverride = "Side Shield 'Switzerland'",
                     DescriptionOverride = "Decorative shield.",
                     CategoryOverride = ModAPI.FindCategory("Misc."),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Side shield3 icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Decorations/Side shield3.png", 2.0f);

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Metal Pole"),
                     NameOverride = "Side Metal Shield",
                     DescriptionOverride = "Metal decorative shield.",
                     CategoryOverride = ModAPI.FindCategory("Misc."),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Side metal shield icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Decorations/Side metal shield.png", 2.0f);

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Metal Pole"),
                     NameOverride = "Side Metal Shield 'Red Cross'",
                     DescriptionOverride = "Metal decorative shield.",
                     CategoryOverride = ModAPI.FindCategory("Misc."),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Side metal shield2 icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Decorations/Side metal shield2.png", 2.0f);

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Metal Pole"),
                     NameOverride = "Side Metal Shield 'Jester'",
                     DescriptionOverride = "Metal decorative shield.",
                     CategoryOverride = ModAPI.FindCategory("Misc."),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Side metal shield3 icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Decorations/Side metal shield3.png", 2.0f);

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Wheel"),
                     NameOverride = "Side Ride Shield",
                     DescriptionOverride = "Horseman's decorative shield.",
                     CategoryOverride = ModAPI.FindCategory("Misc."),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Side ride shield icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Decorations/Side ride shield.png", 2.0f);

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Wheel"),
                     NameOverride = "Side Ride Shield 'Vortex'",
                     DescriptionOverride = "Horseman's decorative shield.",
                     CategoryOverride = ModAPI.FindCategory("Misc."),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Side ride shield2 icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Decorations/Side ride shield2.png", 2.0f);

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Wheel"),
                     NameOverride = "Side Ride Shield 'Star'",
                     DescriptionOverride = "Horseman's decorative shield.",
                     CategoryOverride = ModAPI.FindCategory("Misc."),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Side ride shield3 icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Decorations/Side ride shield3.png", 2.0f);

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Rod"),
                     NameOverride = "Side Buckler",
                     DescriptionOverride = "Decorative dueling shield.",
                     CategoryOverride = ModAPI.FindCategory("Misc."),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Side Buckler icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Decorations/Side Buckler.png");

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Rod"),
                     NameOverride = "Side Leather Buckler",
                     DescriptionOverride = "Decorative dueling shield.",
                     CategoryOverride = ModAPI.FindCategory("Misc."),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Side Buckler2 icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Decorations/Side Buckler2.png");

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Wheel"),
                     NameOverride = "Side Tower Shield",
                     DescriptionOverride = "Decorative tower shield.",
                     CategoryOverride = ModAPI.FindCategory("Misc."),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Side tower shield icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Decorations/Side tower shield.png", 2.0f);

                         Instance.FixColliders();
                     }
                 }
             );

             ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Wheel"),
                     NameOverride = "Side Tower Shield 'Icon'",
                     DescriptionOverride = "...",
                     CategoryOverride = ModAPI.FindCategory("Misc."),
                     ThumbnailOverride = ModAPI.LoadSprite("Icons/Side tower shield2 icon.png"),
                     AfterSpawn = (Instance) =>
                     {
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Decorations/Side tower shield2.png", 2.0f);

                         Instance.FixColliders();
                     }
                 }
             );

  ModAPI.Register(
      new Modification()
      {
          OriginalItem = ModAPI.FindSpawnable("Stick"),
          NameOverride = "Wooden Plate",
          DescriptionOverride = "Medieval utensil element.",
          CategoryOverride = ModAPI.FindCategory("Misc."),
          ThumbnailOverride = ModAPI.LoadSprite("Icons/Wooden plate icon.png"),
          AfterSpawn = (Instance) =>
          {
              Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Decorations/Wooden plate.png");

              Instance.FixColliders();
          }
      }
  );

  ModAPI.Register(
      new Modification()
      {
          OriginalItem = ModAPI.FindSpawnable("Stick"),
          NameOverride = "Wooden Spoon",
          DescriptionOverride = "Large oak spoon.",
          CategoryOverride = ModAPI.FindCategory("Misc."),
          ThumbnailOverride = ModAPI.LoadSprite("Icons/Wooden spoon icon.png"),
          AfterSpawn = (Instance) =>
          {
              Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Decorations/Wooden spoon.png");

              Instance.FixColliders();
          }
      }
  );

  ModAPI.Register(
      new Modification()
      {
          OriginalItem = ModAPI.FindSpawnable("Knife"),
          NameOverride = "Wooden Fork",
          DescriptionOverride = "A fork sharp as my tongue.",
          CategoryOverride = ModAPI.FindCategory("Melee"),
          ThumbnailOverride = ModAPI.LoadSprite("Icons/Wooden fork icon.png"),
          AfterSpawn = (Instance) =>
          {
              Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Wooden fork.png", 2.0f);

              Instance.FixColliders();
          }
      }
  );

  ModAPI.Register(
      new Modification()
      {
          OriginalItem = ModAPI.FindSpawnable("Small I-Beam"),
          NameOverride = "Anvil",
          DescriptionOverride = "The heaviest anvil you've ever seen!",
          CategoryOverride = ModAPI.FindCategory("Misc."),
          ThumbnailOverride = ModAPI.LoadSprite("Icons/Anvil icon.png"),
          AfterSpawn = (Instance) =>
          {
            var phys = Instance.GetComponent<PhysicalBehaviour>();
            Instance.GetComponent<PhysicalBehaviour>().InitialMass = 35f;
            Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 50f;
            Instance.GetComponent<PhysicalBehaviour>().rigidbody.mass = 20.5f;
              Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Decorations/Anvil.png", 2.0f);

              Instance.FixColliders();
          }
      }
  );

  ModAPI.Register(
      new Modification()
      {
          OriginalItem = ModAPI.FindSpawnable("Hammer"),
          NameOverride = "Blacksmith Hammer",
          DescriptionOverride = "The perfect hammer.",
          CategoryOverride = ModAPI.FindCategory("Melee"),
          ThumbnailOverride = ModAPI.LoadSprite("Icons/Blacksmith hammer icon.png"),
          AfterSpawn = (Instance) =>
          {
            var phys = Instance.GetComponent<PhysicalBehaviour>();
            Instance.GetComponent<PhysicalBehaviour>().InitialMass = 1f;
            Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 1f;
            Instance.GetComponent<PhysicalBehaviour>().rigidbody.mass = 2.5f;

              Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Blacksmith hammer.png", 2.0f);

              Instance.FixColliders();
          }
      }
  );

  ModAPI.Register(
      new Modification()
      {
          OriginalItem = ModAPI.FindSpawnable("Hammer"),
          NameOverride = "Spike Hammer",
          DescriptionOverride = "A weighty but effective hammer against opponents. Do not use in a blacksmith!",
          CategoryOverride = ModAPI.FindCategory("Melee"),
          ThumbnailOverride = ModAPI.LoadSprite("Icons/Spike Hammer icon.png"),
          AfterSpawn = (Instance) =>
          {
            var phys = Instance.GetComponent<PhysicalBehaviour>();
            Instance.GetComponent<PhysicalBehaviour>().InitialMass = 1f;
            Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 1f;
            Instance.GetComponent<PhysicalBehaviour>().rigidbody.mass = 5.5f;

              Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Spike Hammer.png", 2.0f);

              Instance.FixColliders();
          }
      }
  );

  ModAPI.Register(
      new Modification()
      {
          OriginalItem = ModAPI.FindSpawnable("Rod"),
          NameOverride = "Cestus",
          DescriptionOverride = "Medieval brass knuckle.",
          CategoryOverride = ModAPI.FindCategory("Melee"),
          ThumbnailOverride = ModAPI.LoadSprite("Icons/Cestus icon.png"),
          AfterSpawn = (Instance) =>
          {
              Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Cestus.png", 1.55f);

              Instance.FixColliders();
          }
      }
  );

  ModAPI.Register(
      new Modification()
      {
          OriginalItem = ModAPI.FindSpawnable("Knife"),
          NameOverride = "Pole",
          DescriptionOverride = "Wooden log pointed at the end. Become a real vampire hunter!",
          CategoryOverride = ModAPI.FindCategory("Melee"),
          ThumbnailOverride = ModAPI.LoadSprite("Icons/Pole icon.png"),
          AfterSpawn = (Instance) =>
          {
              Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Weapons/Pole.png", 2.0f);

              Instance.FixColliders();
            }
        }
    );
        }
    }
}
